import React from 'react';
import { RendererProps } from '../../factory';
import { SchemaCollection, SchemaTpl } from '../../Schema';
import { CollapseSchema } from '../Collapse';
import { FormBaseControl, FormControlSchema } from './Item';
/**
 * FieldSet 表单项集合
 * 文档：https://baidu.gitee.io/amis/docs/components/form/fieldset
 */
export interface FieldSetControlSchema extends Omit<FormBaseControl, 'size'>, Omit<CollapseSchema, 'type' | 'body'> {
    /**
     * 指定为表单项集合
     */
    type: 'fieldset' | 'fieldSet';
    /**
     * 标题展示位置
     */
    titlePosition: 'top' | 'bottom';
    /**
     * 表单项集合
     */
    controls?: Array<FormControlSchema>;
    /**
     * 内容区域
     */
    body?: SchemaCollection;
    /**
     * 标题
     */
    title?: SchemaTpl;
    /**
     * 收起的标题
     */
    collapseTitle?: SchemaTpl;
}
export interface FieldSetProps extends RendererProps, Omit<FieldSetControlSchema, 'type'> {
}
export default class FieldSetControl extends React.Component<FieldSetProps, any> {
    constructor(props: FieldSetProps);
    static defaultProps: {
        titlePosition: string;
        headingClassName: string;
        collapsable: boolean;
    };
    renderBody(): JSX.Element;
    render(): JSX.Element;
}
export declare class FieldSetRenderer extends FieldSetControl {
}
